Trait Writer Copy item path Source pub trait Writer: Send + Sync {
// Required method
fn write (&mut self, to: &Path , data: Record ) -> Result <Path , Error >;
}Expand description Write records to paths.
This is the semantic write interface. Paths are validated Unicode identifiers,
and the data can be either raw bytes or parsed values.
See Reader for discussion of the &mut self requirement.
 Object Safety
This trait is object-safe: you can use Box<dyn Writer>.
Write a record to a path.
Returns the path where data was written. This may differ from the
input path—for example, the HTTP broker returns a handle path like
/outstanding/0 after queuing a request to the root path.
This trait is dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety".